@@ -37,6 +37,7 @@ H5 = "H5"
 H616 = "H616"
 RK3308 = "RK3308"
 RK3399 = "RK3399"
+RK3328 = "RK3328"
 LPC4330 = "LPC4330"
 RK3288 = "RK3288"
 PENTIUM_N3710 = "PENTIUM_N3710"  # SOC Braswell core
@@ -46,5 +47,10 @@ STM32MP157 = "STM32MP157"
 MT8167 = "MT8167"
 ATOM_X5_Z8350 = "X5-Z8350"
 PICO_U2IF = "PICO_U2IF"
+FEATHER_U2IF = "FEATHER_U2IF"
+ITSYBITSY_U2IF = "ITSYBITSY_U2IF"
+QTPY_U2IF = "QTPY_U2IF"
+QT2040_TRINKEY_U2IF = "QT2040_TRINKEY_U2IF"
+
 
 BCM_RANGE = {"BCM2708", "BCM2709", "BCM2711", "BCM2835", "BCM2837"}
